#!/usr/bin/env bash
set -e

#
# Note: It is assumed that the build script will be run as the root user.
#

echo "[+] Building ShakaBrah"
echo "[+] OS: Ubuntu 18.04 LTS"
echo "[+] Author: Offensive Security Labs Team"
echo "[+] Date: 2020-08-14"
echo "[+] Point Value: 5"

echo "[+] Installing utilities"
apt install -y net-tools vim open-vm-tools

echo "[+] Configuring first vector"
echo "[+] Installing Apache and PHP"
apt install -y apache2 libapache2-mod-php

echo "[+] Creating vulnerable website"
rm -rf /var/www/html/index.html
tar -xvf shakabrah-vulnerable-site.tar.gz --directory /var/www/html

echo "[+] Enabling Apache"
systemctl enable apache2
systemctl start apache2

echo "[+] Configuring second vector"
echo "[+] Modifying permissions for vim"
chmod u+s /usr/bin/vim

echo "[+] Configuring firewall"
echo "[+] Installing iptables"
echo "iptables-persistent iptables-persistent/autosave_v4 boolean false" | debconf-set-selections
echo "iptables-persistent iptables-persistent/autosave_v6 boolean false" | debconf-set-selections
apt install -y iptables-persistent

#
# Note: Unless specifically required as part of the exploitation path, please
#       ensure that inbound ICMP and SSH on port 22 are permitted.
#

echo "[+] Applying inbound firewall rules"
iptables -I INPUT 1 -i lo -j ACCEPT
iptables -A INPUT -m conntrack --ctstate NEW,ESTABLISHED,RELATED -j ACCEPT
iptables -A INPUT -p tcp --dport 22 -j ACCEPT
iptables -A INPUT -p tcp --dport 80 -j ACCEPT
iptables -A INPUT -p icmp --icmp-type echo-request -j ACCEPT
iptables -A INPUT -p icmp --icmp-type echo-reply -j ACCEPT
iptables -A INPUT -j DROP

#
# Note: Unless specifically required as part of the exploitation path, please
#       ensure that outbound ICMP, DNS (TCP & UDP) on port 53 and SSH on port 22
#       are permitted.
#

echo "[+] Applying outbound firewall rules"
iptables -A OUTPUT -o lo -j ACCEPT
iptables -A OUTPUT -p tcp --sport 22 -m state --state NEW,ESTABLISHED -j ACCEPT
iptables -A OUTPUT -p tcp --dport 53 -m state --state NEW,ESTABLISHED -j ACCEPT
iptables -A OUTPUT -p udp --dport 53 -m state --state NEW,ESTABLISHED -j ACCEPT
iptables -A OUTPUT -p tcp --dport 80 -m state --state NEW,ESTABLISHED -j ACCEPT
iptables -A OUTPUT -p tcp --sport 80 -m state --state NEW,ESTABLISHED -j ACCEPT
iptables -A OUTPUT -p icmp --icmp-type echo-request -j ACCEPT
iptables -A OUTPUT -p icmp --icmp-type echo-reply -j ACCEPT
iptables -A OUTPUT -j DROP

echo "[+] Saving firewall rules"
service netfilter-persistent save

echo "[+] Disabling IPv6"
echo "net.ipv6.conf.all.disable_ipv6 = 1" >> /etc/sysctl.conf
echo "net.ipv6.conf.default.disable_ipv6 = 1" >> /etc/sysctl.conf
sed -i 's/GRUB_CMDLINE_LINUX_DEFAULT=""/GRUB_CMDLINE_LINUX_DEFAULT="ipv6.disable=1"/' /etc/default/grub
sed -i 's/GRUB_CMDLINE_LINUX=""/GRUB_CMDLINE_LINUX="ipv6.disable=1"/' /etc/default/grub
update-grub

echo "[+] Configuring hostname"
hostnamectl set-hostname shakabrah
cat << EOF > /etc/hosts
127.0.0.1 localhost
127.0.0.1 shakabrah
EOF

echo "[+] Creating users if they don't already exist"
id -u dylan &>/dev/null || useradd -m dylan

echo "[+] Disabling history files"
ln -sf /dev/null /root/.bash_history
ln -sf /dev/null /home/dylan/.bash_history

#
# Note: Unless specifically required as part of the exploitation path, please
#       ensure that root login via SSH is permitted.
#

echo "[+] Enabling root SSH login"
sed -i 's/#PermitRootLogin prohibit-password/PermitRootLogin yes/' /etc/ssh/sshd_config

echo "[+] Setting passwords"
echo "root:CowabungaItsTimeToSurf991" | chpasswd
echo "dylan:CatchThatWaveMyDude751" | chpasswd

echo "[+] Dropping flags"
echo "ca742c7ad27d517527f49531c02f76b8" > /root/proof.txt
echo "9f1642b69b2a23aca3c5863e3f1ffd92" > /home/dylan/local.txt
chmod 0600 /root/proof.txt
chmod 0644 /home/dylan/local.txt
chown dylan:dylan /home/dylan/local.txt 

#
# Note: Please ensure that any artefacts and log files created by the build script or
#       while running the build script are removed afterwards.
#

echo "[+] Cleaning up"
rm -rf /root/build.sh
rm -rf /root/shakabrah-vulnerable-site.tar.gz
rm -rf /root/.cache
rm -rf /root/.viminfo
rm -rf /home/dylan/.sudo_as_admin_successful
rm -rf /home/dylan/.cache
rm -rf /home/dylan/.viminfo
find /var/log -type f -exec sh -c "cat /dev/null > {}" \;
